# This program to calculate bond potential energy.
# Dr. Walter F. de Azevedo Jr. Date: June 17, 2019.
# azevedolab.net

# Import libraries
import numpy as np

# Set up initial values
v_l = 0
nres_ca = 0
nres_n = -1

# Set bond parameters for CA-N 
# Taken from Table 3.4 Cotterill R. Introduction to Biophysics. 
# John Wiley & Sons, LTD West Sussex, 2005.
k_ca_n = 0.0049
l0 = 1.47

# Read PDB
pdbFileIn = input("\nType the PDB file name => ")
fo = open(pdbFileIn,"r")
for line in fo:
    if line[0:6] == "ATOM  " and line[13:15] == "CA":
        nres_ca = int(line[22:26])
        xca,yca,zca = float(line[30:38]), float(line[38:46]), float(line[46:54])
    elif line[0:6] == "ATOM  " and line[13:15] == "N ":
        nres_n = int(line[22:26])
        xn,yn,zn = float(line[30:38]), float(line[38:46]), float(line[46:54])
    elif nres_ca == nres_n:
        l_ca_n = np.sqrt( (xca-xn)**2 + (yca-yn)**2 + (zca-zn)**2 )
        v_l += k_ca_n*(l_ca_n - l0)**2 
        nres_ca = 0
        nres_n = -1

# Close file
fo.close()

print("Bond Energy for N-CA = ",v_l,"aJ")