# This program generates a plot of bond potential energy.
# Dr. Walter F. de Azevedo Jr. Date: June 17, 2019.
# azevedolab.net

# Import libraries
import numpy as np
import matplotlib.pyplot as plt

# Set bond parameters for C-N 
# Taken from Table 3.4 Cotterill R. Introduction to Biophysics. 
# John Wiley & Sons, LTD West Sussex, 2005.
k_C_N = 0.0049
l0 = 1.47

# Define array for interatomic distance (in Angstrom) ( 1 Agstrom = 10^10 m)
x = np.linspace(0.01,5.0,100)

# Calculate energy
V_C_N = k_C_N*(x-l0)**2

# Plot stuff
plt.plot(x,V_C_N)
plt.xlabel("Interatomic distance ($\AA$)")
plt.ylabel("Bond energy (10$^{-18}$J)")
plt.grid(True)
plt.show()
plt.savefig("bond_energy.png")